<?php

namespace AppBundle\Controller;

use AppBundle\Entity\DatosUsuario;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Datosusuario controller.
 *
 */
class DatosUsuarioController extends Controller
{
    /**
     * Lists all datosUsuario entities.
     *
     */
    public function indexAction()
    {
        $em = $this->getDoctrine()->getManager();
        $datosUsuarios = $em->getRepository('AppBundle:DatosUsuario')->findOneByUsuario($this->getUser());

        return $this->render('datosusuario/index.html.twig', array(
            'datosUsuarios' => $datosUsuarios,
        ));
    }

    /**
     * Creates a new datosUsuario entity.
     *
     */
    public function newAction(Request $request)
    {
        if ($this->isGranted('ROLE_EMPRESA'))
        {
            $datosUsuario = new \AppBundle\Entity\DatosUsuarioEmpresa();
        }
        else if ($this->isGranted('ROLE_GRUPO_COM')) 
        {
            $datosUsuario = new \AppBundle\Entity\DatosUsuarioGrupoComunitario();
        }
        else {
            throw new AccessDeniedException($this->get('translator')->trans('cambiar_perfil_sin_permiso'));
        }
        
        $datosUsuario->setUsuario($this->getUser());
        $form = $this->createForm($this->getClaseFormDeUsuario(), $datosUsuario);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->persist($datosUsuario);
            $em->flush();

            return $this->redirectToRoute('perfil_show', array('id' => $datosUsuario->getId()));
        }

        return $this->render('datosusuario/new.html.twig', array(
            'datosUsuario' => $datosUsuario,
            'form' => $form->createView(),
        ));
    }

    /**
     * Finds and displays a datosUsuario entity.
     *
     */
    public function showAction(DatosUsuario $datosUsuario)
    {
        $deleteForm = $this->createDeleteForm($datosUsuario);

        return $this->render('datosusuario/show.html.twig', array(
            'datosUsuario' => $datosUsuario,
            'delete_form' => $deleteForm->createView(),
        ));
    }

    /**
     * Displays a form to edit an existing datosUsuario entity.
     *
     */
    public function editAction(Request $request)
    {
        $em = $this->getDoctrine()->getManager();
        $usuario = $this->getUser();
        $hashEmail =  md5( strtolower( trim($usuario->getEmail())));

        $datosUsuario = $em->getRepository('AppBundle:DatosUsuario')->findOneByUsuario($usuario);
        
        if (!$datosUsuario) {
           if ($this->isGranted('ROLE_EMPRESA'))
           {
               $datosUsuario = new \AppBundle\Entity\DatosUsuarioEmpresa();
           }
           else if ($this->isGranted('ROLE_GRUPO_COM'))
           {
               $datosUsuario = new \AppBundle\Entity\DatosUsuarioGrupoComunitario();
           }
           else {
               throw new AccessDeniedException($this->get('translator')->trans('cambiar_perfil_sin_permiso'));
           }

           $datosUsuario->setUsuario($this->getUser());
           $em->persist($datosUsuario);
                 
           $this->getUser()->setDatosUsuario($datosUsuario);
           
        }
        
        $editForm = $this->createForm($this->getClaseFormDeUsuario(), $datosUsuario);
        $editForm->handleRequest($request);

        if ($editForm->isSubmitted() && $editForm->isValid()) {
            $this->getDoctrine()->getManager()->flush();

             //si completo perfil
           $usuario->setPerfilCompleto(true);
           $em->persist($usuario);
           $em->flush();

           $this->addFlash(
            'success',
            '¡Tus cambios fueron guardados!'
            );

            return $this->redirectToRoute('perfil_edit');
        }

        return $this->render('datosusuario/edit.html.twig', array(
            'datosUsuario' => $datosUsuario,
            'hashEmail' => $hashEmail,
            'edit_form' => $editForm->createView(),
        ));
    }

    public function desconectarAction(Request $request)
    {   
        $response = new JsonResponse();
        $response->setStatusCode(200);
        $result = "Ok";

        if ($request->getMethod="POST") {
            $serviceName = $request->request->get('service_name');
            $em = $this->getDoctrine()->getManager();
            $usuario = $this->getUser();

            $setter = 'set' . ucfirst($serviceName) . 'AccessToken';
            $usuario->$setter("");//remove access token
            if (($request->request->get('habilitar')) === 'true') {
                $setter = 'set' . ucfirst($serviceName) . 'Id';
                $usuario->$setter("");//remove service id
            }
            else {
                $setter = 'set' . ucfirst($serviceName) . 'Id';
                $usuario->$setter("-1");//remove service id and disable
            }   
        }
        else {
            $result = "Error";
        }

        $em->persist($usuario);
        $em->flush();

        $response->setData(array(
            'result' => $result
        ));

        return $response;   
    }
    
    /**
     * Deletes a datosUsuario entity.
     *
     */
    public function deleteAction(Request $request, DatosUsuario $datosUsuario)
    {
        $form = $this->createDeleteForm($datosUsuario);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->remove($datosUsuario);
            $em->flush();
        }

        return $this->redirectToRoute('perfil_index');
    }

    /**
     * Creates a form to delete a datosUsuario entity.
     *
     * @param DatosUsuario $datosUsuario The datosUsuario entity
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createDeleteForm(DatosUsuario $datosUsuario)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl('perfil_delete', array('id' => $datosUsuario->getId())))
            ->setMethod('DELETE')
            ->getForm()
        ;
    }
    
    public function getClaseFormDeUsuario() {
        if ($this->isGranted('ROLE_EMPRESA'))
        {
            return 'AppBundle\Form\DatosUsuarioEmpresaType';
        }
        else if ($this->isGranted('ROLE_GRUPO_COM')) 
        {
            return 'AppBundle\Form\DatosUsuarioGrupoComunitarioType';
        }
        else {
            throw new AccessDeniedException($this->get('translator')->trans('cambiar_perfil_sin_permiso'));
        }
        return 'AppBundle\Form\DatosUsuarioType';
    }
}
