<?php

namespace AppBundle\Controller;

use AppBundle\Entity\Evidencia;
use AppBundle\Entity\EvidenciaImagen;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use AppBundle\Entity\Postulacion;
use Symfony\Component\HttpFoundation\Response;



/**
 * Evidencium controller.
 *
 */
class EvidenciaController extends UploadController
{
    
    /**
     * Creates a new evidencium entity.
     *
     */
    public function newAction(Request $request)
    {
        $id_postulacion = $request->get('postulacion_id');
        $em = $this->getDoctrine()->getManager();
        $postulacion = $em->getRepository('AppBundle:Postulacion')->find($id_postulacion);

        $postulaciones = $this->getUser()->getDatosUsuario()->getPostulaciones();

        $tienePermiso = $postulaciones->contains($postulacion);
        $tienePermiso = $tienePermiso && ($postulacion->estaAceptada() or $postulacion->estaRendida());
        
        $galleryWebPath =  $this->getParameter('upload_directory');


        if ($postulacion and $tienePermiso) {
          $evidencium = $postulacion->getEvidencia();
          
          if ($evidencium) {
              if ($this->getUser()->getDatosUsuario()->esEmpresa()) {
                    $puntaje = $evidencium->getPuntuacionEmpresa();
                }
                else {
                    $puntaje = $evidencium->getPuntuacionGrupo();
                }
          }
          else {
            $puntaje = 0;
            $evidencium = new Evidencia();
            $evidencium->setGrupo($this->getUser()->getDatosUsuario());
            $evidencium->setFechaEntrega(new \DateTime());
          }
          
          $form = $this->createForm('AppBundle\Form\EvidenciaType', $evidencium);
          $form->handleRequest($request);
          if ($form->isSubmitted() && $form->isValid()) {

                $postulacion->setEvidencia($evidencium);

                if ($puntaje && $puntaje != 0) {
                    $postulacion->setResultadoRendida();
                }

                $em = $this->getDoctrine()->getManager();

                $manager = $this->get('oneup_uploader.orphanage_manager')->get('gallery');
                // get files
                // upload all files to the configured storage
                $files = $manager->uploadFiles();
                $filter="gallery";
                
                foreach ($files as $f) {
                    $imagen = new EvidenciaImagen();
                    $imagen->setNombre($f->getFilename());
                    $evidencium->addImage($imagen);
                    $fullSizeImgWebPath=$imagen->getNombre();

                    if (strpos($f->getMimeType(), 'image') !== false) {
                        $thumbAbsPath=$galleryWebPath."thumb/".$imagen->getNombre();
                        $this->writeThumbnail($fullSizeImgWebPath, $thumbAbsPath, $filter);
                    }
                }

                $em->persist($evidencium);
                $em->persist($postulacion);
                $em->flush();

                return $this->redirectToRoute('evidencia_new', array('postulacion_id' => $postulacion->getId()));
                }
            
            if (!$puntaje) {
                    $puntaje = 0;
            }    

            return $this->render('evidencia/new.html.twig', array(
                'puntaje' => $puntaje,
                'postulacion' => $postulacion,
                'evidencium' => $evidencium,
                'upload_dir' => $this->getParameter('upload_directory'),
                'form' => $form->createView(),
            ));

        }
        else {
            throw new AccessDeniedException('No es posible editar la evidencia');
        }
        
    }

    /**
     * Finds and displays a evidencium entity.
     *
     */
    public function showAction(Request $request, Evidencia $evidencium)
    {
        //Show es para empresa
        $form = $this->createForm('AppBundle\Form\EvidenciaShowType', $evidencium);
        $form->handleRequest($request);

        $puntaje = $evidencium->getPuntuacionEmpresa();


        if ($form->isSubmitted() && $form->isValid()) {

            if ($puntaje && $puntaje != 0) {
                $publi =  $evidencium->getPostulacion()->getPublicacion();
                $publi->setEstadoEntregada();
            }
            
            $this->getDoctrine()->getManager()->flush();

            return $this->redirectToRoute('evidencia_show', array('id' => $evidencium->getId()));        

        }

        if (!$puntaje) {
            $puntaje = 0;
        }  
        
        $puntaje_grupo = $evidencium->getPuntuacionGrupo();
        return $this->render('evidencia/show.html.twig', array(
            'puntaje' => $puntaje,
            'postulacion' => $evidencium->getPostulacion(),
            'form' => $form->createView(),
            'evidencium' => $evidencium,
            'puntaje_grupo' => $puntaje_grupo
        ));
    }

    public function deleteFileAction(Request $request){
        return parent::deleteFile($request, "EvidenciaImagen");
    }

    public function getFilesAction(Request $request)
    {
        return parent::getFiles("Evidencia", $request->query->get('file_id'));
    }

    public function tienePermiso($archivo){
        return $archivo->getEvidencia()->getGrupo()->getUsuario() == $this->getUser();
    }
    
    
    public function getImagenAction($id, $thumb) {
        
        $em = $this->getDoctrine()->getManager();
        $entity = $em->getRepository('AppBundle:EvidenciaImagen')->find($id);
        $is_granted = $this->isGranted('IS_AUTHENTICATED_FULLY');
        if ($entity->getHome() or $is_granted) { 
            $documentoUrl = $entity->getNombre();

            $path = $this->getParameter('upload_directory');
            if ($thumb){
                $path .= "thumb/";
            }
            $path .= $documentoUrl;

            $file = file_get_contents($path);
            $ext = strtolower( pathinfo( basename( $path ), PATHINFO_EXTENSION ) );
            $content_type = $this->getContentType($ext);
            
            $headers = array('Content-Type' => $content_type, 
                        'Content-Disposition' => 'inline; filename="'.$documentoUrl.'"');
             return new Response($file, 200, $headers);
        }
        else $this->denyAccessUnlessGranted('IS_AUTHENTICATED_FULLY');
    }
}
