<?php

namespace AppBundle\Controller;

use AppBundle\Entity\Postulacion;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use AppBundle\Entity\Publicacion;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;


/**
 * Postulacion controller.
 *
 */
class PostulacionController extends Controller
{
    /**
     * Lists all postulacion entities.
     *
     */
    public function indexAction(Request $request, $resultado)
    {
        $paginator  = $this->get('knp_paginator');
        $em = $this->getDoctrine()->getManager();
        $criteria = array('grupo'=>$this->getUser()->getDatosUsuario()->getId());
        $resultados = [
            'aceptadas' => 'A',
            'solicitadas' => 'S',
            'rendidas' => 'R'
        ];
        if (array_key_exists($resultado, $resultados)) {
            $criteria['resultado'] = $resultados[$resultado];
        }
        else {
            $criteria['resultado'] = "";
        }
          
        $query = $em->getRepository('AppBundle:Postulacion')->findPostulacion(
                $criteria['resultado'],
                true,
                $this->getUser()->getDatosUsuario()
                );
        
        $pagination = $paginator->paginate(
            $query, /* query NOT result */
            $request->query->getInt('page', 1), /*page number*/
            15 /*limit per page*/
        );

        $cantPostu = $em->getRepository('AppBundle:Postulacion')->countPostulacion(
            'S',$this->getUser()->getDatosUsuario());
            
        $cantAcepta = $em->getRepository('AppBundle:Postulacion')->countPostulacion(
            'A',$this->getUser()->getDatosUsuario());    

        $cantidades = [
            "postulaciones" => $cantPostu,
            "aceptadas" => $cantAcepta,
        ];
        
        return $this->render('postulacion/index.html.twig', array(
            'postulacions' => $pagination,
            'title' => "Postulaciones " . $resultado,
            'cantidades' => $cantidades
        ));

    }

    /**
     * Creates a new postulacion entity.
     *
     */
    public function newAction(Request $request)
    {
        $postulacion = new Postulacion();
        $form = $this->createForm('AppBundle\Form\PostulacionType', $postulacion);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->persist($postulacion);
            $em->flush();

            return $this->redirectToRoute('postular_show', array('id' => $postulacion->getId()));
        }

        return $this->render('postulacion/new.html.twig', array(
            'postulacion' => $postulacion,
            'form' => $form->createView(),
        ));
    }

    /**
     * Finds and displays a postulacion entity.
     *
     */
    public function showAction(Postulacion $postulacion)
    {
        $deleteForm = $this->createDeleteForm($postulacion);

        return $this->render('postulacion/show.html.twig', array(
            'postulacion' => $postulacion,
            'delete_form' => $deleteForm->createView(),
        ));
    }

    /**
     * Displays a form to edit an existing postulacion entity.
     *
     */
    public function editAction(Request $request, Postulacion $postulacion)
    {
        $deleteForm = $this->createDeleteForm($postulacion);
        $editForm = $this->createForm('AppBundle\Form\PostulacionType', $postulacion);
        $editForm->handleRequest($request);

        if ($editForm->isSubmitted() && $editForm->isValid()) {
            $this->getDoctrine()->getManager()->flush();

            return $this->redirectToRoute('postular_edit', array('id' => $postulacion->getId()));
        }

        return $this->render('postulacion/edit.html.twig', array(
            'postulacion' => $postulacion,
            'edit_form' => $editForm->createView(),
            'delete_form' => $deleteForm->createView(),
        ));
    }

    /**
     * Deletes a postulacion entity.
     *
     */
    public function deleteAction(Request $request, Postulacion $postulacion)
    {
        $form = $this->createDeleteForm($postulacion);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->remove($postulacion);
            $em->flush();
        }

        return $this->redirectToRoute('postular_index');
    }

    /**
     * Creates a form to delete a postulacion entity.
     *
     * @param Postulacion $postulacion The postulacion entity
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createDeleteForm(Postulacion $postulacion)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl('postular_delete', array('id' => $postulacion->getId())))
            ->setMethod('DELETE')
            ->getForm()
        ;
    }

    /**
     * Lists all publicacion entities.
     *
     */
    public function indexPublicacionAction(Request $request, $estado)
    {   
        $paginator  = $this->get('knp_paginator');
        $em = $this->getDoctrine()->getManager();
        $criteria = array();
        $estados = [
            'activas' => 'A',
            'pendientes' => 'P',
            'entregadas' => 'E'
        ];
        if (array_key_exists($estado, $estados)) {
            $criteria['estado'] = $estados[$estado];
        }
        
        $query = $em->getRepository('AppBundle:Publicacion')->findVigentes($criteria['estado']);
        $datosUsuario = $em->getRepository('AppBundle:DatosUsuarioGrupoComunitario')->findOneByUsuario($this->getUser());


        
        $pagination = $paginator->paginate(
            $query, /* query NOT result */
            $request->query->getInt('page', 1), /*page number*/
            15 /*limit per page*/
        );


        $cantPostu = $em->getRepository('AppBundle:Postulacion')->countPostulacion(
            'S',$this->getUser()->getDatosUsuario());
            
        $cantAcepta = $em->getRepository('AppBundle:Postulacion')->countPostulacion(
            'A',$this->getUser()->getDatosUsuario());       

        $cantidades = [
            "postulaciones" => $cantPostu,
            "aceptadas" => $cantAcepta,
        ];
        
        return $this->render('postulacion/index_publicacion.html.twig', array(
            'publicacions' => $pagination,
            'title' => "Donaciones " . $estado,
            'cantidades' => $cantidades
        ));
    }

    /**
     * Finds and displays a publicacion entity.
     *
     */
    public function showPublicacionAction(Request $request, Publicacion $publicacion)
    {
        $em = $this->getDoctrine()->getManager();

        $postulacion = null;

        $datosUsuario = $this->getUser()->getDatosUsuario();
        
        $postulacion = $em->getRepository('AppBundle:Postulacion')->findOneBy(array("grupo" => $datosUsuario,"publicacion" => $publicacion));

        
        return $this->render('postulacion/show_publicacion.html.twig', array(
            'publicacion' => $publicacion,
            'postulacion' => $postulacion,
            'upload_dir' => $this->getParameter('upload_directory')
        ));
    }

    public function updatePostulacionAction(Request $request, Publicacion $publicacion)
   {
        $submittedToken = $request->request->get('_csrf_token');
        if (!$this->isCsrfTokenValid('postulacion', $submittedToken)) {
            return new JsonResponse(array('message' => "El token CSRF no es válido. Por favor, intente nuevamente"), 403);
        }
        
        if ($publicacion->estaEntregado()) 
        {
            throw new AccessDeniedException('No es posible realizar esta accion en una publicación ya entregada');
        }
        $em = $this->getDoctrine()->getManager();

        $accion = $request->get('accion');

        $postulacion = null;

        $datosUsuario = $em->getRepository('AppBundle:DatosUsuarioGrupoComunitario')->findOneByUsuario($this->getUser());

        $postulacions = $datosUsuario->getPostulaciones();

        foreach ($postulacions as $postu) {
            //si existe una postulacion con id de la publicacion actual, la asigna a a postulacion
            if ($postu->getPublicacion()->getId() == $publicacion->getId()) {
                $postulacion = $postu;
            }
        }

        $status = "";
        if ($accion == "postular" ) {
            if ($postulacion == null) {
                $postulacion = new Postulacion();
                $postulacion->setResultado("S");
            }
            $postulacion->setEnabled(true);
            $postulacion->setPublicacion($publicacion);
            $postulacion->setGrupo($datosUsuario);
            $postulacion->setFecha(new \DateTime());
            $em->persist($postulacion);
            $em->flush();  
            $status = "postular";
        }
        else if (($accion == "cancelar") && ($postulacion != null)) {
            $postulacion->setEnabled(false);
            $postulacion->setPublicacion($publicacion);
            $postulacion->setGrupo($datosUsuario);
            $em->persist($postulacion);
            $em->flush();  
            $status = "cancelar"; 
        }

        return $this->render('postulacion/show_publicacion.html.twig', array(
                'publicacion' => $publicacion,
                'postulacion' => $postulacion,
                'upload_dir' => $this->getParameter('upload_directory')
            ));
   }
}
