<?php

namespace AppBundle\Controller;

use AppBundle\Entity\Publicacion;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\Filesystem\Filesystem;
use AppBundle\Entity\PublicacionImagen;
use AppBundle\Entity\Solicitud;
use AppBundle\Entity\Postulacion;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use Symfony\Component\HttpFoundation\Response;
/**
 * Publicacion controller.
 *
 */
class PublicacionController extends UploadController
{
    /**
     * Lists all publicacion entities.
     *
     */
    public function indexAction(Request $request, $estado)
    {   
        $paginator  = $this->get('knp_paginator');
        $em = $this->getDoctrine()->getManager();
        $criteria = array('empresa'=>$this->getUser()->getDatosUsuario()->getId());
        $estados = [
            'activas' => 'A',
            'pendientes' => 'P',
            'entregadas' => 'E'
        ];
        if (array_key_exists($estado, $estados)) {
            $criteria['estado'] = $estados[$estado];
        }
        else {
            $criteria['estado'] = "";
        }
                
        $query = $em->getRepository('AppBundle:Publicacion')->findVigentes(
                $criteria['estado'],
                true,
                $this->getUser()->getDatosUsuario()
                );
        
        $pagination = $paginator->paginate(
            $query, /* query NOT result */
            $request->query->getInt('page', 1), /*page number*/
            15 /*limit per page*/
        );

        $cantAbierta = $em->getRepository('AppBundle:Publicacion')->countVigentes(
                'A',$this->getUser()->getDatosUsuario());    
            
        $cantPendiente = $em->getRepository('AppBundle:Publicacion')->countVigentes(
            'P',$this->getUser()->getDatosUsuario());     

        $cantidades = [
            "activas" => $cantAbierta,
            "pendientes" => $cantPendiente,
        ];
                
        return $this->render('publicacion/index.html.twig', array(
            'publicacions' => $pagination,
            'title' => "Donaciones " . $estado,
            'cantidades' => $cantidades
        ));
    }

    /**
     * Creates a new publicacion entity.
     *
     */
    public function newAction(Request $request)
    {
        $publicacion = $this->prepararNuevaPublicacion();
        $form = $this->createForm('AppBundle\Form\PublicacionType', $publicacion);
        $form->handleRequest($request);
        
        $galleryWebPath = $this->getParameter('upload_directory');

        $em = $this->getDoctrine()->getManager();
        if ($form->isSubmitted() && $form->isValid()) {

            $manager = $this->get('oneup_uploader.orphanage_manager')->get('gallery');
            // get files
            // upload all files to the configured storage
            $files = $manager->uploadFiles();
            $filter="gallery";
            
            foreach ($files as $f) {
                $imagen = new PublicacionImagen();
                $imagen->setNombre($f->getFilename());
                $publicacion->addImage($imagen);
                //$fullSizeImgWebPath=$this->getParameter('upload_directory').$imagen->getNombre();
                $fullSizeImgWebPath=$imagen->getNombre();
                $thumbAbsPath=$galleryWebPath."thumb/".$imagen->getNombre();
                $this->writeThumbnail($fullSizeImgWebPath, $thumbAbsPath, $filter);
            }
            
            $em->persist($publicacion);
            $em->flush();

            return $this->redirectToRoute('donar_show', array('id' => $publicacion->getId()));
        }

        $cantAbierta = $em->getRepository('AppBundle:Publicacion')->countVigentes(
            'A',$this->getUser()->getDatosUsuario());    
        
        $cantPendiente = $em->getRepository('AppBundle:Publicacion')->countVigentes(
            'P',$this->getUser()->getDatosUsuario());     

        $cantidades = [
            "activas" => $cantAbierta,
            "pendientes" => $cantPendiente,
        ];

        return $this->render('publicacion/new.html.twig', array(
            'publicacion' => $publicacion,
            'form' => $form->createView(),
            'upload_dir' => $this->getParameter('upload_directory'),
            'cantidades' => $cantidades
        ));
    }
    /**
     * Creates a new publicacion entity.
     *
     */
    public function donarSolicitudAction(Request $request, Solicitud $solicitud)
    {
        if ($solicitud->getCerrada()) {
            throw new AccessDeniedException('Solicitud cerrada');
        }
        
        $publicacion = $this->prepararNuevaPublicacion();
        $publicacion->setTitulo($solicitud->getTitulo());
        $publicacion->setDescripcion($solicitud->getDescripcion());
        $publicacion->setCategoria($solicitud->getCategoria());
        $publicacion->setFechaPublicacion(new \DateTime());
        $publicacion->setFechaFinPublicacion($solicitud->getFechaVencimiento());
        
        
        $form = $this->createForm('AppBundle\Form\PublicacionType', $publicacion, array("solicitud"=>true));
        $form->handleRequest($request);
        
        $galleryWebPath = $this->getParameter('upload_directory');

        $em = $this->getDoctrine()->getManager();
        if ($form->isSubmitted() && $form->isValid()) {

            $manager = $this->get('oneup_uploader.orphanage_manager')->get('gallery');
            // get files
            // upload all files to the configured storage
            $files = $manager->uploadFiles();
            $filter="gallery";
            
            foreach ($files as $f) {
                $imagen = new PublicacionImagen();
                $imagen->setNombre($f->getFilename());
                $publicacion->addImage($imagen);
                //$fullSizeImgWebPath=$this->getParameter('upload_directory').$imagen->getNombre();
                $fullSizeImgWebPath=$imagen->getNombre();
                $thumbAbsPath=$galleryWebPath."thumb/".$imagen->getNombre();
                $this->writeThumbnail($fullSizeImgWebPath, $thumbAbsPath, $filter);
            }
            
            $postulacion = $this->crearPostulacionAceptada($publicacion,$solicitud);
            $solicitud->setCerrada(true);
            $publicacion->setSolicitud($solicitud);
            $em->persist($publicacion);
            $em->persist($postulacion);
            $this->enviarMailConfirmacionGrupo($publicacion,$postulacion);
            
            $em->flush();

            return $this->redirectToRoute('donar_show', array('id' => $publicacion->getId()));
        }

        $cantAbierta = $em->getRepository('AppBundle:Publicacion')->countVigentes(
            'A',$this->getUser()->getDatosUsuario());    
        
        $cantPendiente = $em->getRepository('AppBundle:Publicacion')->countVigentes(
            'P',$this->getUser()->getDatosUsuario());     

        $cantidades = [
            "activas" => $cantAbierta,
            "pendientes" => $cantPendiente,
        ];

        return $this->render('publicacion/new.html.twig', array(
            'publicacion' => $publicacion,
            'form' => $form->createView(),
            'upload_dir' => $this->getParameter('upload_directory'),
            'cantidades' => $cantidades
        ));
    }

    /**
     * Finds and displays a publicacion entity.
     *
     */
    public function showAction(Publicacion $publicacion)
    {   $deshabilitada = false;
        if ($publicacion->estaPendiente() or $publicacion->estaEntregado()) {
            $deshabilitada = true;
        }
        $deleteForm = $this->createDeleteForm($publicacion);

        return $this->render('publicacion/show.html.twig', array(
            'publicacion' => $publicacion,
            'upload_dir' => $this->getParameter('upload_directory'),
            'delete_form' => $deleteForm->createView(),
            'deshabilitada' => $deshabilitada
        ));
    }

    /**
     * Displays a form to edit an existing publicacion entity.
     *
     */
    public function editAction(Request $request, Publicacion $publicacion)
    {
        if ($publicacion->estaPendiente() or $publicacion->estaEntregado()) {
            throw new AccessDeniedException('No es posible editar la publicación');
        }
        $deleteForm = $this->createDeleteForm($publicacion);
        $editForm = $this->createForm('AppBundle\Form\PublicacionType', $publicacion);
        $editForm->handleRequest($request);

        
        $galleryWebPath = $this->getParameter('upload_directory');
        
        if ($editForm->isSubmitted() && $editForm->isValid()) {
            $manager = $this->get('oneup_uploader.orphanage_manager')->get('gallery');
            // get files
            // upload all files to the configured storage
            $files = $manager->uploadFiles();
            $filter="gallery";
            
            foreach ($files as $f) {
                $imagen = new PublicacionImagen();
                $imagen->setNombre($f->getFilename());
                $publicacion->addImage($imagen);
                //$fullSizeImgWebPath=$galleryWebPath.$imagen->getNombre();
                $fullSizeImgWebPath=$imagen->getNombre();
                
                $thumbAbsPath=$galleryWebPath."thumb/".$imagen->getNombre();
                $this->writeThumbnail($fullSizeImgWebPath, $thumbAbsPath, $filter);
            }
            $this->getDoctrine()->getManager()->flush();

            $this->addFlash(
                'success',
                '¡Tus cambios fueron guardados!'
                );
                
            return $this->redirectToRoute('donar_edit', array('id' => $publicacion->getId()));
        }

        $em = $this->getDoctrine()->getManager();

        $cantAbierta = $em->getRepository('AppBundle:Publicacion')->countVigentes(
            'A',$this->getUser()->getDatosUsuario());    
        
        $cantPendiente = $em->getRepository('AppBundle:Publicacion')->countVigentes(
            'P',$this->getUser()->getDatosUsuario());     

        $cantidades = [
            "activas" => $cantAbierta,
            "pendientes" => $cantPendiente,
        ];

        return $this->render('publicacion/edit.html.twig', array(
            'publicacion' => $publicacion,
            'edit_form' => $editForm->createView(),
            'delete_form' => $deleteForm->createView(),
            'upload_dir' => $this->getParameter('upload_directory'),
            'cantidades' => $cantidades
        ));
    }

    /**
     * Acepta a un grupo postulante.
     *
     */
    public function aceptarGrupoAction(Request $request, Publicacion $publicacion)
    { 
        
        $submittedToken = $request->request->get('_csrf_token');
        if (!$this->isCsrfTokenValid('aceptar_postulacion', $submittedToken)) {
            return new JsonResponse(array('message' => "El token CSRF no es válido. Por favor, intente nuevamente"), 403);
        }
        $em = $this->getDoctrine()->getManager();

        $accion = $request->get('accion');
        $id_postulacion = $request->get('id_postulacion');

        $postulacion = $em->getRepository('AppBundle:Postulacion')->find($id_postulacion);
        
        if ($postulacion) {
            $publicacion = $postulacion->getPublicacion();

            if ($accion == "aceptar") {
                $postulacion_aceptada = $em->getRepository('AppBundle:Postulacion')->findBy(array('publicacion' => $publicacion, 'resultado' => 'A'));
                if (!$postulacion_aceptada) {
                    $postulacion->setResultado('A');
                    $publicacion->setEstadoPendiente();
                    $em->persist($postulacion);
                    $em->persist($publicacion);
                    $this->enviarMailConfirmacionGrupo($publicacion,$postulacion);
                }
            }
            elseif ($accion == "cancelar") {
                $postulacion->setResultado('S');
                $publicacion->setEstadoAbierta();
                $em->persist($postulacion);
                $em->persist($publicacion);
            }      
            $em->flush(); 
        
        $deleteForm = $this->createDeleteForm($publicacion);
        
        return $this->render('publicacion/show.html.twig', array(
            'publicacion' => $publicacion,
            'postulacion' => $postulacion,
            'delete_form' => $deleteForm->createView(),
            'upload_dir' => $this->getParameter('upload_directory')
        ));
      }
   }

    /**
     * Deletes a publicacion entity.
     *
     */
    public function deleteAction(Request $request, Publicacion $publicacion)
    {
        $form = $this->createDeleteForm($publicacion);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            
            $filesystem = new Filesystem();
            foreach ($publicacion->getImagenes() as $imagen) {
                if ($imagen && $imagen->getPublicacion()->getEmpresa()->getUsuario() == $this->getUser()) {
                  $filesystem->remove($this->getParameter('upload_directory') . $imagen->getNombre());
                  $filesystem->remove($this->getParameter('upload_directory') . '/thumb/'. $imagen->getNombre());
                }
            }

            $em->remove($publicacion);
            $em->flush();
        }

        return $this->redirectToRoute('donar_index');
    }

    /**
     * Creates a form to delete a publicacion entity.
     *
     * @param Publicacion $publicacion The publicacion entity
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createDeleteForm(Publicacion $publicacion)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl('donar_delete', array('id' => $publicacion->getId())))
            ->setMethod('DELETE')
            ->getForm()
        ;
    }

    public function deleteImageAction(Request $request){
        return parent::deleteFile($request, "PublicacionImagen");
    }

    public function getImagesAction(Request $request)
    {
        return parent::getFiles("Publicacion", $request->query->get('publicacion_id'));
    }
    
    public function tienePermiso($archivo) {
       return $archivo->getPublicacion()->getEmpresa()->getUsuario() == $this->getUser();
    }
    
    private function prepararNuevaPublicacion() {
        $publicacion = new Publicacion();
        $publicacion->setEmpresa($this->getUser()->getDatosUsuario());
        $publicacion->setFechaAlta(new \DateTime());
        $publicacion->setEstadoAbierta();
        return $publicacion;
    }

    public function crearPostulacionAceptada($publicacion,$solicitud) {
        $postulacion = new Postulacion();
        $postulacion->setPublicacion($publicacion);
        $postulacion->setGrupo($solicitud->getGrupo());
        $postulacion->setResultadoAceptada();
        $postulacion->setEnabled(true);
        $postulacion->setFecha(new \DateTime());
        $publicacion->setEstadoPendiente();
        return $postulacion;
    }

    public function enviarMailConfirmacionGrupo($publicacion, $postulacion) {
    {
        //envia confirmación al grupo
        $empresa_datos_usuario = $publicacion->getEmpresa();
        $grupo_datos_usuario = $postulacion->getPublicacion()->getEmpresa();

        $template = 'email/grupo_publicacion_confirmada.html.twig';
        if ($publicacion->getSolicitud()) {
            $template = 'email/grupo_solicitud_creada.html.twig';
        }
        $message = (new \Swift_Message('Donación confirmada'))
            ->setFrom($this->getParameter('mailer_sender_address'))
            ->setTo($grupo_datos_usuario->getUsuario()->getEmail())
            ->addPart(
                $this->renderView(
                    $template,
                    ['empresa_datos_usuario' => $empresa_datos_usuario,
                    'grupo_datos_usuario' => $grupo_datos_usuario,
                    'publicacion' => $publicacion]
                ),
                'text/html'
            )
        ;

        $this->get('mailer')->send($message);
    }
    }
    
    
    public function getImagenAction($id, $thumb) {
        $em = $this->getDoctrine()->getManager();
        $entity = $em->getRepository('AppBundle:PublicacionImagen')->find($id);
        $documentoUrl = $entity->getNombre();
        
        $path = $this->getParameter('upload_directory');
        if ($thumb){
            $path .= "thumb/";
        }
        $path .= $documentoUrl;
        
        $file = file_get_contents($path);
        $ext = strtolower( pathinfo( basename( $path ), PATHINFO_EXTENSION ) );
        $content_type = $this->getContentType($ext);

        $headers = array('Content-Type' => $content_type, 
                    'Content-Disposition' => 'inline; filename="'.$documentoUrl.'"');
         return new Response($file, 200, $headers);
    }

}
