<?php

namespace AppBundle\Controller;

use AppBundle\Entity\Solicitud;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;

/**
 * Solicitud controller.
 *
 */
class SolicitudController extends Controller
{
    /**
     * Lists all solicitud entities.
     *
     */
    
    
    public function indexAction()
    {
        //GRUPO
        $em = $this->getDoctrine()->getManager();
        $cantPostu = $em->getRepository('AppBundle:Postulacion')->countPostulacion(
            'S',$this->getUser()->getDatosUsuario());
            
        $cantAcepta = $em->getRepository('AppBundle:Postulacion')->countPostulacion(
            'A',$this->getUser()->getDatosUsuario());    

        $cantidades = [
            "postulaciones" => $cantPostu,
            "aceptadas" => $cantAcepta,
        ];
        
        $solicituds = $em->getRepository('AppBundle:Solicitud')->findByGrupo($this->getUser()->getDatosUsuario());

        return $this->render('solicitud/index_grupo.html.twig', array(
            'solicituds' => $solicituds,
            'cantidades' => $cantidades
        ));
    }
    public function verSolicitudesAction(Request $request)
    {
        //EMPRESA
        $em = $this->getDoctrine()->getManager();
        $paginator  = $this->get('knp_paginator');

        $dql   = "SELECT s FROM AppBundle:Solicitud s WHERE s.cerrada <> true and s.fechaVencimiento >= CURRENT_DATE() ";
        $query = $em->createQuery($dql);
        
        $solicituds = $paginator->paginate(
            $query, /* query NOT result */
            $request->query->getInt('page', 1), /*page number*/
            15 /*limit per page*/
        );
        
        $cantAbierta = $em->getRepository('AppBundle:Publicacion')->countVigentes(
                'A',$this->getUser()->getDatosUsuario());    
            
        $cantPendiente = $em->getRepository('AppBundle:Publicacion')->countVigentes(
            'P',$this->getUser()->getDatosUsuario());     

        $cantidades = [
            "activas" => $cantAbierta,
            "pendientes" => $cantPendiente,
        ];
        
        //$solicituds = $em->getRepository('AppBundle:Solicitud')->findByGrupo($this->getUser()->getDatosUsuario());

        return $this->render('solicitud/index_empresa.html.twig', array(
            'solicituds' => $solicituds,
            'cantidades' => $cantidades
        ));
    }

    /**
     * Creates a new solicitud entity.
     *
     */
    public function newAction(Request $request)
    {
        $solicitud = new Solicitud();
        $solicitud->setCerrada(false);
        $solicitud->setGrupo($this->getUser()->getDatosUsuario());
        $form = $this->createForm('AppBundle\Form\SolicitudType', $solicitud);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->persist($solicitud);
            $em->flush();

            return $this->redirectToRoute('solicitud_show', array('id' => $solicitud->getId()));
        }

        return $this->render('solicitud/new.html.twig', array(
            'solicitud' => $solicitud,
            'form' => $form->createView(),
        ));
    }

    /**
     * Finds and displays a solicitud entity.
     *
     */
    public function showAction(Solicitud $solicitud)
    {
        $deleteForm = $this->createDeleteForm($solicitud);

        return $this->render('solicitud/show.html.twig', array(
            'solicitud' => $solicitud,
            'delete_form' => $deleteForm->createView(),
            'borrar_deshabilitado' => $solicitud->getCerrada()
        ));
    }

    /**
     * Displays a form to edit an existing solicitud entity.
     *
     */
    public function editAction(Request $request, Solicitud $solicitud)
    {
        $deleteForm = $this->createDeleteForm($solicitud);
        $editForm = $this->createForm('AppBundle\Form\SolicitudType', $solicitud);
        $editForm->handleRequest($request);

        if ($editForm->isSubmitted() && $editForm->isValid()) {
            $this->getDoctrine()->getManager()->flush();

            return $this->redirectToRoute('solicitud_edit', array('id' => $solicitud->getId()));
        }

        return $this->render('solicitud/edit.html.twig', array(
            'solicitud' => $solicitud,
            'edit_form' => $editForm->createView(),
            'delete_form' => $deleteForm->createView(),
        ));
    }

    /**
     * Deletes a solicitud entity.
     *
     */
    public function deleteAction(Request $request, Solicitud $solicitud)
    {
        if ($solicitud->getCerrada()) {
            throw new AccessDeniedException('Solicitud cerrada');
        }
        $form = $this->createDeleteForm($solicitud);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->remove($solicitud);
            $em->flush();
        }

        return $this->redirectToRoute('solicitud_index');
    }

    /**
     * Creates a form to delete a solicitud entity.
     *
     * @param Solicitud $solicitud The solicitud entity
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createDeleteForm(Solicitud $solicitud)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl('solicitud_delete', array('id' => $solicitud->getId())))
            ->setMethod('DELETE')
            ->getForm()
        ;
    }
}
