<?php

namespace AppBundle\Controller;

use AppBundle\Entity\User;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;

/**
 * User controller.
 *
 */
class UserController extends Controller
{
    /**
     * Lists all user entities.
     *
     */
    public function indexAction(Request $request, $solo_deshabilitados = false, $solo_esperando = false)
    {
        $em = $this->getDoctrine()->getManager();
        $dql   = "SELECT u,m,d FROM AppBundle:User u
                  LEFT JOIN u.datos_usuario d
                  LEFT JOIN d.municipio m";
        if ($solo_deshabilitados) {
            $dql .= ' where u.enabled = false AND u.fechaCambio IS NOT NULL';
        }
        else if ($solo_esperando) {
          $dql .= ' where u.enabled = false AND u.fechaCambio IS NULL';
        }

        if ($this->isGranted('ROLE_MUNICIPIO')){
            $municipio_id = $this->getUser()->getDatosUsuario()->getMunicipio()->getId();

            if ($solo_deshabilitados || $solo_esperando) {
            $dql .= ' AND m.id = ' . $municipio_id;
            }
            else {
                $dql .= ' where m.id = ' . $municipio_id;
            }
        }

        $query = $em->createQuery($dql);
        
        
        $paginator  = $this->get('knp_paginator');
        $pagination = $paginator->paginate(
            $query, /* query NOT result */
            $request->query->getInt('page', 1), /*page number*/
            15 /*limit per page*/
        );
        
        // parameters to template
        return $this->render('user/index.html.twig', array('users' => $pagination, 'solo_deshabilitados' => $solo_deshabilitados, 'solo_esperando' => $solo_esperando));
        //return $this->render('user/index.html.twig', array('users' => $users, ));
    }

    public function sendEmailAction(User $user)
    {
        $mail = $user->getEmail();

        $message = (new \Swift_Message('Usuario DarBA habilitado'))
            ->setFrom($this->getParameter('mailer_sender_address'))
            ->setTo($mail)
            /*->setBody(
                $this->renderView(
                    'email/usuario_habilitado.html.twig',
                    ['mail' => $mail]
                ),
                'text/html'
            )*/

            // you can remove the following code if you don't define a text version for your emails
            ->addPart(
                $this->renderView(
                    'email/usuario_habilitado.html.twig',
                    ['mail' => $mail]
                ),
                'text/html'
            )
        ;

        $this->get('mailer')->send($message);
    }

    public function toggleStatusAction(Request $request, User $user) {
        $response = new JsonResponse();
        
        $submittedToken = $request->request->get('_csrf_token');
        if (!$this->isCsrfTokenValid('habilitar_usuarios', $submittedToken)) {
            $response->setData(array(
                "error" => "El token CSRF no es válido. Por favor, intente nuevamente"
            ));
            return $response;
        }

        if ($user->isEnabled()) {
            $user->setEnabled(false);
        } 
        else {
            $user->setEnabled(true);
            $this->sendEmailAction($user);
        }
        $user->setFechaCambio(new \DateTime());
        $usuario_id = $this->getUser()->getId();
        $user->setIdUsuarioCambio($usuario_id);
        
        $em = $this->getDoctrine()->getManager();
        $em->persist($user);
        $em->flush();
        $response->setData(array(
                "enabled" => $user->isEnabled()
            ));
        return $response;
    }
    /**
     * Creates a new user entity.
     *
     */
    public function newAction(Request $request)
    {
        $user = new User();
        $form = $this->createForm('AppBundle\Form\UserBackType', $user);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            
            if ($form->get("rol")->getData() == "grupo_com") {
                $roles = array("ROLE_GRUPO_COM");    
                $datos_usuario = new \AppBundle\Entity\DatosUsuarioGrupoComunitario();
            }
            else if ($form->get("rol")->getData() == "municipio") {
                $roles = array("ROLE_MUNICIPIO");    
                $datos_usuario = new \AppBundle\Entity\DatosUsuarioMunicipio();
            }
            else 
            {
                $roles =array("ROLE_EMPRESA"); 
                 $datos_usuario = new \AppBundle\Entity\DatosUsuarioEmpresa();
            }
                   
            $email = $user->getEmail();
            $datos_usuario_cargado = $user->getDatosUsuario();
            if ($user = $this->register($user->getEmail(), $user->getUsername(), $user->getPlainPassword(), $roles)) {
                
                $datos_usuario = $datos_usuario->importarDeAnonimo($datos_usuario_cargado);
                $datos_usuario->setUsuario($user);
                if ($this->isGranted('ROLE_MUNICIPIO')) {
                    // si tiene rol municipio, el usuario nuevo/editado sera el del municipio.
                    $datos_usuario->setMunicipio($this->getUser()->getDatosUsuario()->getMunicipio());                                    
                }    
                $em->persist($datos_usuario);
                $em->persist($user);
                $em->flush();
                
                return $this->redirectToRoute('user_show', array('id' => $user->getId()));
            }
            else {
                $mensaje = "Ya está registrado el email {$email}";
                $this->addFlash('danger',$mensaje);
            }
            
        }

        return $this->render('user/new.html.twig', array(
            'user' => $user,
            'form' => $form->createView(),
        ));
    }

    /**
     * Finds and displays a user entity.
     *
     */
    public function showAction(User $user)
    {
        $em = $this->getDoctrine()->getManager();

        $publicacions = array();
        $postulacions = array();

        $datos_usuario = $user->getDatosUsuario();
        if ($datos_usuario->esGrupoComunitario()) {
            $postulacions = $datos_usuario->getPostulaciones();
        }
        else {
            if ($datos_usuario->esEmpresa()) {
                $publicacions = $em->getRepository('AppBundle:Publicacion')->findPublicaciones(
                    null,
                    false,
                    $datos_usuario,
                    null,
                    false);
            }    
        }

        if ($this->isGranted('ROLE_SUPER_ADMIN') || ($this->isGranted('ROLE_MUNICIPIO') && $this->getUser()->getDatosUsuario()->getMunicipio() == $user->getDatosUsuario()->getMunicipio())) {
            $deleteForm = $this->createDeleteForm($user);
            return $this->render('user/show.html.twig', array(
                'user' => $user,
                'postulacions' => $postulacions,
                'publicacions' => $publicacions,              
                'delete_form' => $deleteForm->createView(),
            ));
        }
        throw new AccessDeniedException($this->get('translator')->trans('cambiar_usuario_sin_permiso'));
    }

    /**
     * Displays a form to edit an existing user entity.
     *
     */
    public function editAction(Request $request, User $user)
    {
        if ($this->isGranted('ROLE_SUPER_ADMIN') || ($this->isGranted('ROLE_MUNICIPIO') && $this->getUser()->getDatosUsuario()->getMunicipio() == $user->getDatosUsuario()->getMunicipio())) {

        //Mejorar esto, para poder editar admin, municipio, etc...
        if (($user->getDatosUsuario()) and $user->getDatosUsuario()->esGrupoComunitario()) {
            $roles = array("ROLE_GRUPO_COM");
            $formType = "grupo_com";
        }
        else if (($user->getDatosUsuario()) and $user->getDatosUsuario()->esEmpresa()) {
            $roles =array("ROLE_EMPRESA"); 
            $formType = "empresa";            
        }
        else if (($user->getDatosUsuario()) and $user->getDatosUsuario()->esMunicipio()) {
            $roles =array("ROLE_MUNICIPIO"); 
            $formType = "municipio";    
        }
        else  {
          //$roles =array("ROLE_EMPRESA"); 
            $formType = null;
        }

        $deleteForm = $this->createDeleteForm($user);
                
        $editForm = $this->createForm('AppBundle\Form\UserBackType', $user, array("type"=>$formType));
        $editForm->handleRequest($request);

        if ($editForm->isSubmitted() && $editForm->isValid()) {

            if ($this->isGranted('ROLE_MUNICIPIO')) {
                // si tiene rol municipio, el usuario nuevo/editado sera el del municipio.
                $user->getDatosUsuario()->setMunicipio($this->getUser()->getDatosUsuario()->getMunicipio());
            }   

            $userManager = $this->container->get('fos_user.user_manager');
            $userManager->updatePassword($user);

            $this->getDoctrine()->getManager()->flush();          

            $this->addFlash(
                'success',
                '¡Tus cambios fueron guardados!'
                );

            return $this->redirectToRoute('user_edit', array('id' => $user->getId()));
        }

        return $this->render('user/edit.html.twig', array(
            'user' => $user,
            'edit_form' => $editForm->createView(),
            'delete_form' => $deleteForm->createView(),
        ));
      }
      throw new AccessDeniedException($this->get('translator')->trans('cambiar_usuario_sin_permiso'));
    }

    /**
     * Deletes a user entity.
     *
     */
    public function deleteAction(Request $request, User $user)
    {
        if ($this->isGranted('ROLE_SUPER_ADMIN') || ($this->isGranted('ROLE_MUNICIPIO') && $this->getUser()->getDatosUsuario()->getMunicipio() == $user->getDatosUsuario()->getMunicipio())) {
            $form = $this->createDeleteForm($user);
            $form->handleRequest($request);

            if ($form->isSubmitted() && $form->isValid()) {
                $em = $this->getDoctrine()->getManager();
                $em->remove($user);
                $em->flush();
            }

            return $this->redirectToRoute('user_index');
        }
      throw new AccessDeniedException($this->get('translator')->trans('cambiar_usuario_sin_permiso'));
    }

    /**
     * Creates a form to delete a user entity.
     *
     * @param User $user The user entity
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createDeleteForm(User $user)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl('user_delete', array('id' => $user->getId())))
            ->setMethod('DELETE')
            ->getForm()
        ;
    }


    private function register($email,$username,$password, $roles){
      $userManager = $this->get('fos_user.user_manager');

      // Or you can use the doctrine entity manager if you want instead the fosuser manager
      // to find 
      //$em = $this->getDoctrine()->getManager();
      //$usersRepository = $em->getRepository("mybundleuserBundle:User");
      // or use directly the namespace and the name of the class 
      // $usersRepository = $em->getRepository("mybundle\userBundle\Entity\User");
      //$email_exist = $usersRepository->findOneBy(array('email' => $email));
      
      $email_exist = $userManager->findUserByEmail($email);

      // Check if the user exists to prevent Integrity constraint violation error in the insertion
      if($email_exist){
          return false;
      }

      $user = $userManager->createUser();
      //$user->setUsername($username);
      $user->setUsername($email);
      $user->setEmail($email);
      $user->setEmailCanonical($email);
      $user->setEnabled(1); // enable the user or enable it later with a confirmation token in the email
      // this method will encrypt the password with the default settings :)
      $user->setPlainPassword($password);
      $user->setRoles($roles);
      $userManager->updateUser($user);

      return $user;
   }

}
