<?php

namespace AppBundle\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Symfony\Component\Validator\Mapping\ClassMetadata;
use Symfony\Bridge\Doctrine\Validator\Constraints\UniqueEntity;

use Symfony\Component\Validator\Constraints as Assert;
/**
 * DatosUsuario
 */
abstract class DatosUsuario
{
    
     /**
     * Add LatLng
     *
     * @param \AppBundle\Entity\LatLng $latlng
     *
     * @return DatosUsuarioGrupoComunitario
     */
    public function addLatLng(\AppBundle\Entity\LatLng $latlng)
    {
        // Bidirectional Ownership
        $latlng->setDatosUsuario($this);
        
        $this->latlngs[] = $latlng;
        
        return $this;
    }
    
    /**
     * Remove LatLng
     *
     * @param \AppBundle\Entity\LatLng $latlng
     */
    public function removeLatLng(\AppBundle\Entity\LatLng $latlng)
    {
        $this->latlngs->removeElement($latlng);
    }
    
    public function __construct() {
        $this->actividad = new ArrayCollection();
        $this->latlngs = new ArrayCollection();
    }
    /**
     * @var integer
     */
    private $id;


    /**
     * Get id
     *
     * @return integer
     */
    public function getId()
    {
        return $this->id;
    }
    /**
     * @var string
     */
    private $nombre_responsable;


    /**
     * Set nombreResponsable
     *
     * @param string $nombreResponsable
     *
     * @return DatosUsuario
     */
    public function setNombreResponsable($nombreResponsable)
    {
        $this->nombre_responsable = $nombreResponsable;

        return $this;
    }

    /**
     * Get nombreResponsable
     *
     * @return string
     */
    public function getNombreResponsable()
    {
        return $this->nombre_responsable;
    }
    /**
     * @var string
     */
    private $nombre;


    /**
     * Set nombre
     *
     * @param string $nombre
     *
     * @return DatosUsuario
     */
    public function setNombre($nombre)
    {
        $this->nombre = $nombre;

        return $this;
    }

    /**
     * Get nombre
     *
     * @return string
     */
    public function getNombre()
    {
        return $this->nombre;
    }
    /**
     * @var string
     */
    private $direccion;

    /**
     * @var string
     */
    private $cp;


    /**
     * Set direccion
     *
     * @param string $direccion
     *
     * @return DatosUsuario
     */
    public function setDireccion($direccion)
    {
        $this->direccion = $direccion;

        return $this;
    }

    /**
     * Get direccion
     *
     * @return string
     */
    public function getDireccion()
    {
        return $this->direccion;
    }

    /**
     * Set cp
     *
     * @param string $cp
     *
     * @return DatosUsuario
     */
    public function setCp($cp)
    {
        $this->cp = $cp;

        return $this;
    }

    /**
     * Get cp
     *
     * @return string
     */
    public function getCp()
    {
        return $this->cp;
    }
    /**
     * @var \AppBundle\Entity\User
     */
    private $usuario;


    /**
     * Set usuario
     *
     * @param \AppBundle\Entity\User $usuario
     *
     * @return DatosUsuario
     */
    public function setUsuario(\AppBundle\Entity\User $usuario)
    {
        $this->usuario = $usuario;

        return $this;
    }

    /**
     * Get usuario
     *
     * @return \AppBundle\Entity\User
     */
    public function getUsuario()
    {
        return $this->usuario;
    }
    
    
    private $actividad;
    
    public function getActividad() {
        return $this->actividad;
    }

    /**
     * Add actividad
     *
     * @param \AppBundle\Entity\Actividad $actividad
     *
     * @return DatosUsuario
     */
    public function addActividad(\AppBundle\Entity\Actividad $actividad)
    {
        $this->actividad[] = $actividad;

        return $this;
    }

    /**
     * Remove actividad
     *
     * @param \AppBundle\Entity\Actividad $actividad
     */
    public function removeActividad(\AppBundle\Entity\Actividad $actividad)
    {
        $this->actividad->removeElement($actividad);
    }
    /**
     * @var string
     */
    private $lat;

    /**
     * @var string
     */
    private $lng;


    /**
     * Set lat
     *
     * @param string $lat
     *
     * @return DatosUsuario
     */
    public function setLat($lat)
    {
        $this->lat = $lat;

        return $this;
    }

    /**
     * Get lat
     *
     * @return string
     */
    public function getLat()
    {
        return $this->lat;
    }

    /**
     * Set lng
     *
     * @param string $lng
     *
     * @return DatosUsuario
     */
    public function setLng($lng)
    {
        $this->lng = $lng;

        return $this;
    }

    /**
     * Get lng
     *
     * @return string
     */
    public function getLng()
    {
        return $this->lng;
    }


    public function esGrupoComunitario() {
        return false;
    }
    
    public function esEmpresa() {
    	return false;
    }
    
    public function esMunicipio() {
    	return false;
    }

    public function importarDeAnonimo($datos_usuario_viejo) {
                $this->setNombre($datos_usuario_viejo->getNombre());
                $this->setNombreResponsable($datos_usuario_viejo->getNombreResponsable());
                $this->setDireccion($datos_usuario_viejo->getDireccion());
                $this->setCp($datos_usuario_viejo->getCp());
                $this->setMunicipio($datos_usuario_viejo->getMunicipio());
                return $this;
    }
    
   private $latlngs;
   
   public function getLatLngs() {
        return $this->latlngs;
   }
   
   public static function loadValidatorMetadata(ClassMetadata $metadata)
    {
        $metadata->addPropertyConstraint('cp', new Assert\NotBlank());
        $metadata->addPropertyConstraint('nombre', new Assert\NotBlank());

       

        $metadata->addConstraint(new UniqueEntity(array(
            'fields'  => 'nombre',
            'message' => "Nombre ya utilizado",
        )));
        
    }

    protected $municipio;


    /**
     * Get the value of municipio
     */ 
    public function getMunicipio()
    {
        return $this->municipio;
    }

    /**
     * Set the value of municipio
     *
     * @return  self
     */ 
    public function setMunicipio($municipio)
    {
        $this->municipio = $municipio;

        return $this;
    }
}
