<?php

/*
 * This file is part of the FOSUserBundle package.
 *
 * (c) FriendsOfSymfony <http://friendsofsymfony.github.com/>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace AppBundle\Form;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\TextType;

use AppBundle\Form\DatosUsuarioGrupoComunitarioType;
use AppBundle\Form\DatosUsuarioEmpresaType;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Form\FormEvents;
use Symfony\Component\Form\FormEvent;
use Karser\Recaptcha3Bundle\Form\Recaptcha3Type;
use Karser\Recaptcha3Bundle\Validator\Constraints\Recaptcha3;

class RegistrationType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder->add('rol', ChoiceType::class, [
                        'choices' => ['Empresa' => "empresa",'Organización' => "grupo_com"],
                        'mapped' => false,
                        'label' => "Tipo de Usuario"
                    ])
                ->remove('username');
                //if ($options["type"] == null)
                $builder->add('datos_usuario', DatosUsuarioRegistroType::class, [
            'label' => ' ',
        ]);
                $builder->add('captcha', Recaptcha3Type::class, [
                    'constraints' => new Recaptcha3(),
                ]);
                /*else if ($options["type"] == "empresa")
                        $builder->add('datos_usuario', DatosUsuarioEmpresaRegistroType::class);
                else if ($options["type"] == "grupo_com") {
                        $builder->add('datos_usuario', DatosUsuarioGrupoComunitarioRegistroType::class);
                }*/
                $builder->addEventListener(FormEvents::PRE_SUBMIT, array($this, 'onPreSetData'));
                $builder->addEventListener(FormEvents::POST_SUBMIT, array($this, 'onPostSubmit'));
    }
    
    public function onPreSetData(FormEvent $event)
    {
        $form = $event->getForm();
        $submittedData = $event->getData();
        //$user = $event->getData();
        if (isset($submittedData["rol"]) && $submittedData["rol"] == "empresa") {
            $form->add('datos_usuario', DatosUsuarioEmpresaRegistroType::class, [
            'label' => ' ',
        ]);
        }
        else if (isset($submittedData["rol"]) && $submittedData["rol"] == "grupo_com") {
            $form->add('datos_usuario', DatosUsuarioGrupoComunitarioRegistroType::class, [
            'label' => ' ',
        ]);
        }
        
    }
    
    public function onPostSubmit(FormEvent $event)
    {
        //No debería hacer falta esto
        $user = $event->getData();
        $datos_usuario = $user->getDatosUsuario();
        $datos_usuario->setUsuario($user);

    }
 
    public function getParent()
    {
        return 'FOS\UserBundle\Form\Type\RegistrationFormType';

        // Or for Symfony < 2.8
        // return 'fos_user_registration';
    }

    public function getBlockPrefix()
    {
        return 'app_user_registration';
    }

    // For Symfony 2.x
    public function getName()
    {
        return $this->getBlockPrefix();
    }
    
   public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults(array(
            'type' => null,
        ));
    }
    
    
    
}
